@@ -1,4 +1,5 @@
 import { pdk_projen } from 'aws-prototyping-sdk';
+import { ApprovalLevel } from 'projen/lib/awscdk';
 
 const monorepo = new pdk_projen.NxMonorepoProject({
   defaultReleaseBranch: 'mainline',
@@ -12,9 +13,9 @@ new pdk_projen.PDKPipelineTsProject({
   cdkVersion: '2.0.0',
   appEntrypoint: 'pipeline.ts',
   parent: monorepo,
+  requireApproval: ApprovalLevel.NEVER,
   outdir: 'packages/infra',
   deps: ['aws-prototyping-sdk'],
-  context: {},
 });
 
 monorepo.synth();
